==> 5.0.2%2B304.tar.gz: android/src/main/java/com/huawei/hms/flutter/push/receiver/BackgroundMessageBroadcastReceiver.java <==
/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package com.huawei.hms.flutter.push.receiver;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;

import com.huawei.hms.flutter.push.HeadlessPushPlugin;
import com.huawei.hms.flutter.push.constants.Param;
import com.huawei.hms.push.RemoteMessage;

import io.flutter.view.FlutterMain;

public class BackgroundMessageBroadcastReceiver extends BroadcastReceiver {
    private static final String TAG = BackgroundMessageBroadcastReceiver.class.getSimpleName();

    public static final String BACKGROUND_REMOTE_MESSAGE = "com.huawei.hms.flutter.push.receiver.BACKGROUND_REMOTE_MESSAGE";

    @Override
    public void onReceive(Context context, Intent intent) {
        FlutterMain.ensureInitializationComplete(context, null);
        if (intent != null) {
            final String action = intent.getAction();
            if (BACKGROUND_REMOTE_MESSAGE.equals(action)) {
                Bundle result = intent.getExtras();
                Log.d("Receiver-java", intent.getExtras().toString());
                if (result != null) {
                    HeadlessPushPlugin headLess = new HeadlessPushPlugin(context);
                    headLess.handleBackgroundMessage(context, (RemoteMessage) result.get(Param.MESSAGE.code()));
                    Log.i("Receiver-java", result.toString());
                }
            }
        }
    }
}

==> 5.3.0%2B304.tar.gz: android/src/main/java/com/huawei/hms/flutter/push/receiver/BackgroundMessageBroadcastReceiver.java <==
/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package com.huawei.hms.flutter.push.receiver;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;

import com.huawei.hms.flutter.push.backgroundmessaging.BackgroundMessagingService;

public class BackgroundMessageBroadcastReceiver extends BroadcastReceiver {
    private static final String TAG = BackgroundMessageBroadcastReceiver.class.getSimpleName();

    public static final String BACKGROUND_REMOTE_MESSAGE
        = "com.huawei.hms.flutter.push.receiver.BACKGROUND_REMOTE_MESSAGE";

    @Override
    public void onReceive(Context context, final Intent intent) {
        if (intent != null) {
            final String action = intent.getAction();
            if (BACKGROUND_REMOTE_MESSAGE.equals(action)) {
                Bundle result = intent.getExtras();
                if (result != null) {
                    BackgroundMessagingService.enqueueWork(context, intent);
                }
            }
        }
    }
}
